<?php
/**
 * The template for displaying custom menus
 *
 * @package Catch Themes
 * @subpackage Catch_Box_Pro
 * @since Catch Box Pro 1.0
 */


if ( ! function_exists( 'catchbox_page_menu_args' ) ) :
/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function catchbox_page_menu_args( $args ) {
    $args['show_home'] = true;
    return $args;
}
endif; //catchbox_page_menu_args

add_filter( 'wp_page_menu_args', 'catchbox_page_menu_args' );


if ( ! function_exists( 'catchbox_page_menu_active' ) ) :
/**
 * Replacing classed in default wp_page_menu
 *
 * REPLACE "current_page_item" WITH CLASS "current-menu-item"
 * REPLACE "current_page_ancestor" WITH CLASS "current-menu-ancestor"
 */
function catchbox_page_menu_active( $text ){
    $replace = array(
        // List of classes to replace with "active"
        'current_page_item' => 'current-menu-item',
        'current_page_ancestor' => 'current-menu-ancestor',
    );
    $text = str_replace(array_keys($replace), $replace, $text);
        return $text;
}
endif; //catchbox_page_menu_active

add_filter( 'wp_page_menu', 'catchbox_page_menu_active' );


if ( ! function_exists( 'catchbox_wp_page_menu' ) ) :
/**
 * Remove div from wp_page_menu() and replace with ul.
 * @uses wp_page_menu filter
 */
function catchbox_wp_page_menu( $page_markup ) {
    preg_match('/^<div class=\"([a-z0-9-_]+)\">/i', $page_markup, $matches);
        $divclass = $matches[1];
        $replace = array('<div class="'.$divclass.'">', '</div>');
        $new_markup = str_replace($replace, '', $page_markup);
        $new_markup = preg_replace('/^<ul>/i', '<ul class="'.$divclass.'">', $new_markup);
        return $new_markup;
}
endif; //catchbox_wp_page_menu

add_filter( 'wp_page_menu', 'catchbox_wp_page_menu' );


if ( ! function_exists( 'catchbox_header_menu' ) ) :
/**
 * Header Menu
 *
 * @since Catch Box 1.2.1
 */
function catchbox_header_menu() { 
    //Getting Ready to load options data
    global $catchbox_options_settings;
    $options = $catchbox_options_settings;

    $classes = "mobile-menu-anchor page-menu";

    // Header Left Mobile Menu Anchor
    if ( has_nav_menu( 'primary' ) ) {
        $classes = "mobile-menu-anchor primary-menu";
    }
    ?>
    <div class="menu-access-wrap mobile-header-menu clearfix">
        <?php if ( empty ($options ['disable_responsive'] ) ) { ?>
            <div id="mobile-header-left-menu" class="<?php echo $classes; ?>">
                <?php 
                $hide_mobile_menu_labels = isset( $options ['hide_mobile_menu_labels'] ) ? $options ['hide_mobile_menu_labels'] : 0;
                
                $label = isset( $options['primary_mobile_menu_label'] ) ? $options['primary_mobile_menu_label'] : esc_html__( 'Menu', 'catch-box-pro' );
                
                $labelclass = "mobile-menu-text";
                
                if ( !empty ( $hide_mobile_menu_labels ) ) {
                    $labelclass = "screen-reader-text";
                }
                ?>
                <a href="#mobile-header-left-nav" id="menu-toggle-primary" class="genericon genericon-menu">
                    <span class="<?php echo esc_attr( $labelclass ); ?>"><?php echo esc_attr( $label ); ?></span>
                </a>
            </div><!-- #mobile-header-left-menu -->
            
            <?php
            if ( !empty ($options ['enable_sec_menu'] ) && has_nav_menu( 'secondary', 'catch-box-pro' ) ) :
                    $menuclass = "mobile-enable"; ?>
                    <div id="mobile-header-right-menu" class="mobile-menu-anchor secondary-menu">
                        <?php 
                        $hide_mobile_menu_labels = isset( $options ['hide_mobile_menu_labels'] ) ? $options ['hide_mobile_menu_labels'] : 0;
                        $label = isset( $options['secondary_mobile_menu_label'] ) ? $options['secondary_mobile_menu_label'] : esc_html__( 'Secondary Menu', 'catch-box-pro' );
                        $labelclass = "mobile-menu-text";
                        if ( !empty ( $hide_mobile_menu_labels ) ) {
                            $labelclass = "screen-reader-text";
                        }
                        ?>
                        <a href="#mobile-header-right-nav" id="menu-toggle-secondary" class="genericon genericon-menu">
                            <span class="<?php echo $labelclass; ?>"><?php echo esc_attr( $label ); ?></span>
                        </a>
                    </div><!-- #mobile-header-right-menu -->
                <?php else :
                    $menuclass = "mobile-disable";
                endif; ?>
        <?php } ?>

        <div id="site-header-menu-primary" class="site-header-menu">
            <nav id="access" class="main-navigation menu-focus" role="navigation" aria-label="<?php esc_attr_e( 'Primary Menu', 'catch-box-pro' ); ?>">
                <h3 class="screen-reader-text"><?php _e( 'Primary menu', 'catch-box-pro' ); ?></h3>
                <?php
                    if ( has_nav_menu( 'primary', 'catch-box-pro' ) ) {
                        $args = array(
                            'theme_location'    => 'primary',
                            'container_class'   => 'menu-header-container',
                            'items_wrap'        => '<ul class="menu">%3$s</ul>'
                        );
                        wp_nav_menu( $args );
                    }
                    else {
                        echo '<div class="menu-header-container">';
                            wp_page_menu( array( 'menu_class'  => 'menu' ) );
                        echo '</div>';
                    }
                ?>
            </nav><!-- #access -->
        </div><!-- .site-header-menu -->

        <?php if ( has_nav_menu( 'secondary' ) ) { ?>
            <div id="site-header-menu-secondary" class="site-header-menu">
                <nav id="access-secondary" class="<?php echo $menuclass; ?>"  role="navigation" aria-label="<?php esc_attr_e( 'Secondary Menu', 'catch-box-pro' ); ?>">
                    <h3 class="screen-reader-text"><?php _e( 'Secondary menu', 'catch-box-pro' ); ?></h3>
                    <?php wp_nav_menu( array( 'theme_location'  => 'secondary', 'container_class' => 'menu-secondary-container' ) );  ?>
                </nav><!-- #access-secondary -->
            </div><!-- .site-header-menu -->
        <?php } ?>
    </div><!-- .menu-access-wrap -->
<?php
}
endif; //catchbox_header_menu

// Load Header Menu in  catchbox_after_headercontent hook
add_action( 'catchbox_after_headercontent', 'catchbox_header_menu', 20 );


if ( ! function_exists( 'catchbox_footer_menu_display' ) ) :
/**
 * Footer Menu
 *
 * @since Catch Box 4.0
 */
function catchbox_footer_menu_display() {
    if ( has_nav_menu( 'footer' ) ) {
        // Check is footer menu is enable or not
        //Getting Ready to load options data
        global $catchbox_options_settings;
        
        $options = $catchbox_options_settings;
        
        $menuclass = "mobile-disable";
        ?>

        <?php 
        if ( empty ($options ['disable_responsive'] ) && !empty ($options ['enable_footer_menu'] ) ) {
                ?>
            <div id="mobile-footer-menu" class="menu-access-wrap clearfix">
            
                <?php   
                $hide_mobile_menu_labels = isset( $options ['hide_mobile_menu_labels'] ) ? $options ['hide_mobile_menu_labels'] : 0;
                
                $label = isset( $options['footer_mobile_menu_label'] ) ? $options['footer_mobile_menu_label'] : esc_html__( 'Footer Menu', 'catch-box-pro' );
                
                $labelclass = "mobile-menu-text";
                
                if ( !empty ( $hide_mobile_menu_labels ) ) {
                    $labelclass = "screen-reader-text";
                }
                ?>
                <div class="mobile-menu-anchor">
                    <a href="#mobile-footer-nav" id="menu-toggle-footer" class="genericon genericon-menu">
                        <span class="<?php echo esc_attr( $labelclass ); ?>"><?php echo esc_attr( $label ); ?></span>
                    </a>
                </div><!-- .mobile-menu-anchor -->
        
            <?php 
            
            $menuclass = "mobile-enable";
        } 
        ?>

            <div id="site-footer-mobile-menu" class="site-footer-menu">
                <nav id="access-footer" class="<?php echo $menuclass; ?>" role="navigation" aria-label="<?php esc_attr_e( 'Footer Menu', 'catch-box-pro' ); ?>">
                    <h3 class="screen-reader-text"><?php _e( 'Footer menu', 'catch-box-pro' ); ?></h3>
                    <?php wp_nav_menu( array( 'theme_location'  => 'footer', 'container_class' => 'menu-footer-container', 'depth' => 1 ) );  ?>
                </nav><!-- #access-footer -->
            </div><!-- .site-footer-menu -->

        <?php if ( empty ($options ['disable_responsive'] ) && !empty ($options ['enable_footer_menu'] ) ) { ?>
        </div><!-- #mobile-footer-menu -->
        <?php
        }
    }
}
endif; //catchbox_footer_menu_display
add_action( 'catchbox_footer_menu', 'catchbox_footer_menu_display', 10 );